from ROOT import TLorentzVector, TMath

#A function, that take few particles' four-vectors as an input and 
#calculates the observable based on the provided key (obsName)
observablesDict = {
    '(jet1).Px()':                                                                                        (lambda jet1, jet2, boson1, boson2: (jet1).Px()), 
    '(jet1).Py()':                                                                                        (lambda jet1, jet2, boson1, boson2: (jet1).Py()), 
    '(jet1).Pz()':                                                                                        (lambda jet1, jet2, boson1, boson2: (jet1).Pz()), 
    '(jet1).E()':                                                                                         (lambda jet1, jet2, boson1, boson2: (jet1).E()), 
    '(jet1).Eta()':                                                                                       (lambda jet1, jet2, boson1, boson2: (jet1).Eta()), 
    '(jet1).Phi()':                                                                                       (lambda jet1, jet2, boson1, boson2: (jet1).Phi()), 
    '(jet1).M()':                                                                                         (lambda jet1, jet2, boson1, boson2: (jet1).M()), 
    '(jet1).P()':                                                                                         (lambda jet1, jet2, boson1, boson2: (jet1).P()), 
    '(jet2).Px()':                                                                                        (lambda jet1, jet2, boson1, boson2: (jet2).Px()), 
    '(jet2).Py()':                                                                                        (lambda jet1, jet2, boson1, boson2: (jet2).Py()), 
    '(jet2).Pz()':                                                                                        (lambda jet1, jet2, boson1, boson2: (jet2).Pz()), 
    '(jet2).E()':                                                                                         (lambda jet1, jet2, boson1, boson2: (jet2).E()), 
    '(jet2).Eta()':                                                                                       (lambda jet1, jet2, boson1, boson2: (jet2).Eta()), 
    '(jet2).Phi()':                                                                                       (lambda jet1, jet2, boson1, boson2: (jet2).Phi()), 
    '(jet2).M()':                                                                                         (lambda jet1, jet2, boson1, boson2: (jet2).M()), 
    '(jet2).P()':                                                                                         (lambda jet1, jet2, boson1, boson2: (jet2).P()), 
    '(jet1 + jet2).Px()':                                                                                 (lambda jet1, jet2, boson1, boson2: (jet1 + jet2).Px()), 
    '(jet1 + jet2).Py()':                                                                                 (lambda jet1, jet2, boson1, boson2: (jet1 + jet2).Py()), 
    '(jet1 + jet2).Pz()':                                                                                 (lambda jet1, jet2, boson1, boson2: (jet1 + jet2).Pz()), 
    '(jet1 + jet2).E()':                                                                                  (lambda jet1, jet2, boson1, boson2: (jet1 + jet2).E()), 
    '(jet1 + jet2).Eta()':                                                                                (lambda jet1, jet2, boson1, boson2: (jet1 + jet2).Eta()), 
    '(jet1 + jet2).Phi()':                                                                                (lambda jet1, jet2, boson1, boson2: (jet1 + jet2).Phi()), 
    '(jet1 + jet2).M()':                                                                                  (lambda jet1, jet2, boson1, boson2: (jet1 + jet2).M()), 
    '(jet1 + jet2).P()':                                                                                  (lambda jet1, jet2, boson1, boson2: (jet1 + jet2).P()), 
    '(jet1 - jet2).Px()':                                                                                 (lambda jet1, jet2, boson1, boson2: (jet1 - jet2).Px()), 
    '(jet1 - jet2).Py()':                                                                                 (lambda jet1, jet2, boson1, boson2: (jet1 - jet2).Py()), 
    '(jet1 - jet2).Pz()':                                                                                 (lambda jet1, jet2, boson1, boson2: (jet1 - jet2).Pz()), 
    '(jet1 - jet2).E()':                                                                                  (lambda jet1, jet2, boson1, boson2: (jet1 - jet2).E()), 
    '(jet1 - jet2).Eta()':                                                                                (lambda jet1, jet2, boson1, boson2: (jet1 - jet2).Eta()), 
    '(jet1 - jet2).Phi()':                                                                                (lambda jet1, jet2, boson1, boson2: (jet1 - jet2).Phi()), 
    '(jet1 - jet2).M()':                                                                                  (lambda jet1, jet2, boson1, boson2: (jet1 - jet2).M()), 
    '(jet1 - jet2).P()':                                                                                  (lambda jet1, jet2, boson1, boson2: (jet1 - jet2).P()), 
    '(boson1).Px()':                                                                                      (lambda jet1, jet2, boson1, boson2: (boson1).Px()), 
    '(boson1).Py()':                                                                                      (lambda jet1, jet2, boson1, boson2: (boson1).Py()), 
    '(boson1).Pz()':                                                                                      (lambda jet1, jet2, boson1, boson2: (boson1).Pz()), 
    '(boson1).E()':                                                                                       (lambda jet1, jet2, boson1, boson2: (boson1).E()), 
    '(boson1).Eta()':                                                                                     (lambda jet1, jet2, boson1, boson2: (boson1).Eta()), 
    '(boson1).Phi()':                                                                                     (lambda jet1, jet2, boson1, boson2: (boson1).Phi()), 
    '(boson1).P()':                                                                                       (lambda jet1, jet2, boson1, boson2: (boson1).P()), 
    '(jet1 + boson1).Px()':                                                                               (lambda jet1, jet2, boson1, boson2: (jet1 + boson1).Px()), 
    '(jet1 + boson1).Py()':                                                                               (lambda jet1, jet2, boson1, boson2: (jet1 + boson1).Py()), 
    '(jet1 + boson1).Pz()':                                                                               (lambda jet1, jet2, boson1, boson2: (jet1 + boson1).Pz()), 
    '(jet1 + boson1).E()':                                                                                (lambda jet1, jet2, boson1, boson2: (jet1 + boson1).E()), 
    '(jet1 + boson1).Eta()':                                                                              (lambda jet1, jet2, boson1, boson2: (jet1 + boson1).Eta()), 
    '(jet1 + boson1).Phi()':                                                                              (lambda jet1, jet2, boson1, boson2: (jet1 + boson1).Phi()), 
    '(jet1 + boson1).M()':                                                                                (lambda jet1, jet2, boson1, boson2: (jet1 + boson1).M()), 
    '(jet1 + boson1).P()':                                                                                (lambda jet1, jet2, boson1, boson2: (jet1 + boson1).P()), 
    '(jet1 - boson1).Px()':                                                                               (lambda jet1, jet2, boson1, boson2: (jet1 - boson1).Px()), 
    '(jet1 - boson1).Py()':                                                                               (lambda jet1, jet2, boson1, boson2: (jet1 - boson1).Py()), 
    '(jet1 - boson1).Pz()':                                                                               (lambda jet1, jet2, boson1, boson2: (jet1 - boson1).Pz()), 
    '(jet1 - boson1).E()':                                                                                (lambda jet1, jet2, boson1, boson2: (jet1 - boson1).E()), 
    '(jet1 - boson1).Eta()':                                                                              (lambda jet1, jet2, boson1, boson2: (jet1 - boson1).Eta()), 
    '(jet1 - boson1).Phi()':                                                                              (lambda jet1, jet2, boson1, boson2: (jet1 - boson1).Phi()), 
    '(jet1 - boson1).M()':                                                                                (lambda jet1, jet2, boson1, boson2: (jet1 - boson1).M()), 
    '(jet1 - boson1).P()':                                                                                (lambda jet1, jet2, boson1, boson2: (jet1 - boson1).P()), 
    '(jet2 + boson1).Px()':                                                                               (lambda jet1, jet2, boson1, boson2: (jet2 + boson1).Px()), 
    '(jet2 + boson1).Py()':                                                                               (lambda jet1, jet2, boson1, boson2: (jet2 + boson1).Py()), 
    '(jet2 + boson1).Pz()':                                                                               (lambda jet1, jet2, boson1, boson2: (jet2 + boson1).Pz()), 
    '(jet2 + boson1).E()':                                                                                (lambda jet1, jet2, boson1, boson2: (jet2 + boson1).E()), 
    '(jet2 + boson1).Eta()':                                                                              (lambda jet1, jet2, boson1, boson2: (jet2 + boson1).Eta()), 
    '(jet2 + boson1).Phi()':                                                                              (lambda jet1, jet2, boson1, boson2: (jet2 + boson1).Phi()), 
    '(jet2 + boson1).M()':                                                                                (lambda jet1, jet2, boson1, boson2: (jet2 + boson1).M()), 
    '(jet2 + boson1).P()':                                                                                (lambda jet1, jet2, boson1, boson2: (jet2 + boson1).P()), 
    '(jet2 - boson1).Px()':                                                                               (lambda jet1, jet2, boson1, boson2: (jet2 - boson1).Px()), 
    '(jet2 - boson1).Py()':                                                                               (lambda jet1, jet2, boson1, boson2: (jet2 - boson1).Py()), 
    '(jet2 - boson1).Pz()':                                                                               (lambda jet1, jet2, boson1, boson2: (jet2 - boson1).Pz()), 
    '(jet2 - boson1).E()':                                                                                (lambda jet1, jet2, boson1, boson2: (jet2 - boson1).E()), 
    '(jet2 - boson1).Eta()':                                                                              (lambda jet1, jet2, boson1, boson2: (jet2 - boson1).Eta()), 
    '(jet2 - boson1).Phi()':                                                                              (lambda jet1, jet2, boson1, boson2: (jet2 - boson1).Phi()), 
    '(jet2 - boson1).M()':                                                                                (lambda jet1, jet2, boson1, boson2: (jet2 - boson1).M()), 
    '(jet2 - boson1).P()':                                                                                (lambda jet1, jet2, boson1, boson2: (jet2 - boson1).P()), 
    '(jet1 + jet2 + boson1).Px()':                                                                        (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 + boson1).Px()), 
    '(jet1 + jet2 + boson1).Py()':                                                                        (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 + boson1).Py()), 
    '(jet1 + jet2 + boson1).Pz()':                                                                        (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 + boson1).Pz()), 
    '(jet1 + jet2 + boson1).E()':                                                                         (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 + boson1).E()), 
    '(jet1 + jet2 + boson1).Eta()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 + boson1).Eta()), 
    '(jet1 + jet2 + boson1).Phi()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 + boson1).Phi()), 
    '(jet1 + jet2 + boson1).M()':                                                                         (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 + boson1).M()), 
    '(jet1 + jet2 + boson1).P()':                                                                         (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 + boson1).P()), 
    '(jet1 + jet2 - boson1).Px()':                                                                        (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 - boson1).Px()), 
    '(jet1 + jet2 - boson1).Py()':                                                                        (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 - boson1).Py()), 
    '(jet1 + jet2 - boson1).Pz()':                                                                        (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 - boson1).Pz()), 
    '(jet1 + jet2 - boson1).E()':                                                                         (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 - boson1).E()), 
    '(jet1 + jet2 - boson1).Eta()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 - boson1).Eta()), 
    '(jet1 + jet2 - boson1).Phi()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 - boson1).Phi()), 
    '(jet1 + jet2 - boson1).M()':                                                                         (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 - boson1).M()), 
    '(jet1 + jet2 - boson1).P()':                                                                         (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 - boson1).P()), 
    '(jet1 - jet2 + boson1).Px()':                                                                        (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 + boson1).Px()), 
    '(jet1 - jet2 + boson1).Py()':                                                                        (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 + boson1).Py()), 
    '(jet1 - jet2 + boson1).Pz()':                                                                        (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 + boson1).Pz()), 
    '(jet1 - jet2 + boson1).E()':                                                                         (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 + boson1).E()), 
    '(jet1 - jet2 + boson1).Eta()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 + boson1).Eta()), 
    '(jet1 - jet2 + boson1).Phi()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 + boson1).Phi()), 
    '(jet1 - jet2 + boson1).M()':                                                                         (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 + boson1).M()), 
    '(jet1 - jet2 + boson1).P()':                                                                         (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 + boson1).P()), 
    '(jet1 - jet2 - boson1).Px()':                                                                        (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 - boson1).Px()), 
    '(jet1 - jet2 - boson1).Py()':                                                                        (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 - boson1).Py()), 
    '(jet1 - jet2 - boson1).Pz()':                                                                        (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 - boson1).Pz()), 
    '(jet1 - jet2 - boson1).E()':                                                                         (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 - boson1).E()), 
    '(jet1 - jet2 - boson1).Eta()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 - boson1).Eta()), 
    '(jet1 - jet2 - boson1).Phi()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 - boson1).Phi()), 
    '(jet1 - jet2 - boson1).M()':                                                                         (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 - boson1).M()), 
    '(jet1 - jet2 - boson1).P()':                                                                         (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 - boson1).P()), 
    '(boson2).Px()':                                                                                      (lambda jet1, jet2, boson1, boson2: (boson2).Px()), 
    '(boson2).Py()':                                                                                      (lambda jet1, jet2, boson1, boson2: (boson2).Py()), 
    '(boson2).E()':                                                                                       (lambda jet1, jet2, boson1, boson2: (boson2).E()), 
    '(boson2).Phi()':                                                                                     (lambda jet1, jet2, boson1, boson2: (boson2).Phi()), 
    '(boson2).P()':                                                                                       (lambda jet1, jet2, boson1, boson2: (boson2).P()), 
    '(jet1 + boson2).Px()':                                                                               (lambda jet1, jet2, boson1, boson2: (jet1 + boson2).Px()), 
    '(jet1 + boson2).Py()':                                                                               (lambda jet1, jet2, boson1, boson2: (jet1 + boson2).Py()), 
    '(jet1 + boson2).E()':                                                                                (lambda jet1, jet2, boson1, boson2: (jet1 + boson2).E()), 
    '(jet1 + boson2).Phi()':                                                                              (lambda jet1, jet2, boson1, boson2: (jet1 + boson2).Phi()), 
    '(jet1 + boson2).M()':                                                                                (lambda jet1, jet2, boson1, boson2: (jet1 + boson2).M()), 
    '(jet1 + boson2).P()':                                                                                (lambda jet1, jet2, boson1, boson2: (jet1 + boson2).P()), 
    '(jet1 - boson2).Px()':                                                                               (lambda jet1, jet2, boson1, boson2: (jet1 - boson2).Px()), 
    '(jet1 - boson2).Py()':                                                                               (lambda jet1, jet2, boson1, boson2: (jet1 - boson2).Py()), 
    '(jet1 - boson2).E()':                                                                                (lambda jet1, jet2, boson1, boson2: (jet1 - boson2).E()), 
    '(jet1 - boson2).Phi()':                                                                              (lambda jet1, jet2, boson1, boson2: (jet1 - boson2).Phi()), 
    '(jet1 - boson2).M()':                                                                                (lambda jet1, jet2, boson1, boson2: (jet1 - boson2).M()), 
    '(jet1 - boson2).P()':                                                                                (lambda jet1, jet2, boson1, boson2: (jet1 - boson2).P()), 
    '(jet2 + boson2).Px()':                                                                               (lambda jet1, jet2, boson1, boson2: (jet2 + boson2).Px()), 
    '(jet2 + boson2).Py()':                                                                               (lambda jet1, jet2, boson1, boson2: (jet2 + boson2).Py()), 
    '(jet2 + boson2).E()':                                                                                (lambda jet1, jet2, boson1, boson2: (jet2 + boson2).E()), 
    '(jet2 + boson2).Phi()':                                                                              (lambda jet1, jet2, boson1, boson2: (jet2 + boson2).Phi()), 
    '(jet2 + boson2).M()':                                                                                (lambda jet1, jet2, boson1, boson2: (jet2 + boson2).M()), 
    '(jet2 + boson2).P()':                                                                                (lambda jet1, jet2, boson1, boson2: (jet2 + boson2).P()), 
    '(jet2 - boson2).Px()':                                                                               (lambda jet1, jet2, boson1, boson2: (jet2 - boson2).Px()), 
    '(jet2 - boson2).Py()':                                                                               (lambda jet1, jet2, boson1, boson2: (jet2 - boson2).Py()), 
    '(jet2 - boson2).E()':                                                                                (lambda jet1, jet2, boson1, boson2: (jet2 - boson2).E()), 
    '(jet2 - boson2).Phi()':                                                                              (lambda jet1, jet2, boson1, boson2: (jet2 - boson2).Phi()), 
    '(jet2 - boson2).M()':                                                                                (lambda jet1, jet2, boson1, boson2: (jet2 - boson2).M()), 
    '(jet2 - boson2).P()':                                                                                (lambda jet1, jet2, boson1, boson2: (jet2 - boson2).P()), 
    '(jet1 + jet2 + boson2).Px()':                                                                        (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 + boson2).Px()), 
    '(jet1 + jet2 + boson2).Py()':                                                                        (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 + boson2).Py()), 
    '(jet1 + jet2 + boson2).E()':                                                                         (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 + boson2).E()), 
    '(jet1 + jet2 + boson2).Phi()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 + boson2).Phi()), 
    '(jet1 + jet2 + boson2).M()':                                                                         (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 + boson2).M()), 
    '(jet1 + jet2 + boson2).P()':                                                                         (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 + boson2).P()), 
    '(jet1 + jet2 - boson2).Px()':                                                                        (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 - boson2).Px()), 
    '(jet1 + jet2 - boson2).Py()':                                                                        (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 - boson2).Py()), 
    '(jet1 + jet2 - boson2).E()':                                                                         (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 - boson2).E()), 
    '(jet1 + jet2 - boson2).Phi()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 - boson2).Phi()), 
    '(jet1 + jet2 - boson2).M()':                                                                         (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 - boson2).M()), 
    '(jet1 + jet2 - boson2).P()':                                                                         (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 - boson2).P()), 
    '(jet1 - jet2 + boson2).Px()':                                                                        (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 + boson2).Px()), 
    '(jet1 - jet2 + boson2).Py()':                                                                        (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 + boson2).Py()), 
    '(jet1 - jet2 + boson2).E()':                                                                         (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 + boson2).E()), 
    '(jet1 - jet2 + boson2).Phi()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 + boson2).Phi()), 
    '(jet1 - jet2 + boson2).M()':                                                                         (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 + boson2).M()), 
    '(jet1 - jet2 + boson2).P()':                                                                         (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 + boson2).P()), 
    '(jet1 - jet2 - boson2).Px()':                                                                        (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 - boson2).Px()), 
    '(jet1 - jet2 - boson2).Py()':                                                                        (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 - boson2).Py()), 
    '(jet1 - jet2 - boson2).E()':                                                                         (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 - boson2).E()), 
    '(jet1 - jet2 - boson2).Phi()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 - boson2).Phi()), 
    '(jet1 - jet2 - boson2).M()':                                                                         (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 - boson2).M()), 
    '(jet1 - jet2 - boson2).P()':                                                                         (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 - boson2).P()), 
    '(boson1 + boson2).Px()':                                                                             (lambda jet1, jet2, boson1, boson2: (boson1 + boson2).Px()), 
    '(boson1 + boson2).Py()':                                                                             (lambda jet1, jet2, boson1, boson2: (boson1 + boson2).Py()), 
    '(boson1 + boson2).E()':                                                                              (lambda jet1, jet2, boson1, boson2: (boson1 + boson2).E()), 
    '(boson1 + boson2).Phi()':                                                                            (lambda jet1, jet2, boson1, boson2: (boson1 + boson2).Phi()), 
    '(boson1 + boson2).M()':                                                                              (lambda jet1, jet2, boson1, boson2: (boson1 + boson2).M()), 
    '(boson1 + boson2).P()':                                                                              (lambda jet1, jet2, boson1, boson2: (boson1 + boson2).P()), 
    '(boson1 - boson2).Px()':                                                                             (lambda jet1, jet2, boson1, boson2: (boson1 - boson2).Px()), 
    '(boson1 - boson2).Py()':                                                                             (lambda jet1, jet2, boson1, boson2: (boson1 - boson2).Py()), 
    '(boson1 - boson2).E()':                                                                              (lambda jet1, jet2, boson1, boson2: (boson1 - boson2).E()), 
    '(boson1 - boson2).Phi()':                                                                            (lambda jet1, jet2, boson1, boson2: (boson1 - boson2).Phi()), 
    '(boson1 - boson2).M()':                                                                              (lambda jet1, jet2, boson1, boson2: (boson1 - boson2).M()), 
    '(boson1 - boson2).P()':                                                                              (lambda jet1, jet2, boson1, boson2: (boson1 - boson2).P()), 
    '(jet1 + boson1 + boson2).Px()':                                                                      (lambda jet1, jet2, boson1, boson2: (jet1 + boson1 + boson2).Px()), 
    '(jet1 + boson1 + boson2).Py()':                                                                      (lambda jet1, jet2, boson1, boson2: (jet1 + boson1 + boson2).Py()), 
    '(jet1 + boson1 + boson2).E()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet1 + boson1 + boson2).E()), 
    '(jet1 + boson1 + boson2).Phi()':                                                                     (lambda jet1, jet2, boson1, boson2: (jet1 + boson1 + boson2).Phi()), 
    '(jet1 + boson1 + boson2).M()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet1 + boson1 + boson2).M()), 
    '(jet1 + boson1 + boson2).P()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet1 + boson1 + boson2).P()), 
    '(jet1 + boson1 - boson2).Px()':                                                                      (lambda jet1, jet2, boson1, boson2: (jet1 + boson1 - boson2).Px()), 
    '(jet1 + boson1 - boson2).Py()':                                                                      (lambda jet1, jet2, boson1, boson2: (jet1 + boson1 - boson2).Py()), 
    '(jet1 + boson1 - boson2).E()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet1 + boson1 - boson2).E()), 
    '(jet1 + boson1 - boson2).Phi()':                                                                     (lambda jet1, jet2, boson1, boson2: (jet1 + boson1 - boson2).Phi()), 
    '(jet1 + boson1 - boson2).M()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet1 + boson1 - boson2).M()), 
    '(jet1 + boson1 - boson2).P()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet1 + boson1 - boson2).P()), 
    '(jet1 - boson1 + boson2).Px()':                                                                      (lambda jet1, jet2, boson1, boson2: (jet1 - boson1 + boson2).Px()), 
    '(jet1 - boson1 + boson2).Py()':                                                                      (lambda jet1, jet2, boson1, boson2: (jet1 - boson1 + boson2).Py()), 
    '(jet1 - boson1 + boson2).E()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet1 - boson1 + boson2).E()), 
    '(jet1 - boson1 + boson2).Phi()':                                                                     (lambda jet1, jet2, boson1, boson2: (jet1 - boson1 + boson2).Phi()), 
    '(jet1 - boson1 + boson2).M()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet1 - boson1 + boson2).M()), 
    '(jet1 - boson1 + boson2).P()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet1 - boson1 + boson2).P()), 
    '(jet1 - boson1 - boson2).Px()':                                                                      (lambda jet1, jet2, boson1, boson2: (jet1 - boson1 - boson2).Px()), 
    '(jet1 - boson1 - boson2).Py()':                                                                      (lambda jet1, jet2, boson1, boson2: (jet1 - boson1 - boson2).Py()), 
    '(jet1 - boson1 - boson2).E()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet1 - boson1 - boson2).E()), 
    '(jet1 - boson1 - boson2).Phi()':                                                                     (lambda jet1, jet2, boson1, boson2: (jet1 - boson1 - boson2).Phi()), 
    '(jet1 - boson1 - boson2).M()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet1 - boson1 - boson2).M()), 
    '(jet1 - boson1 - boson2).P()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet1 - boson1 - boson2).P()), 
    '(jet2 + boson1 + boson2).Px()':                                                                      (lambda jet1, jet2, boson1, boson2: (jet2 + boson1 + boson2).Px()), 
    '(jet2 + boson1 + boson2).Py()':                                                                      (lambda jet1, jet2, boson1, boson2: (jet2 + boson1 + boson2).Py()), 
    '(jet2 + boson1 + boson2).E()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet2 + boson1 + boson2).E()), 
    '(jet2 + boson1 + boson2).Phi()':                                                                     (lambda jet1, jet2, boson1, boson2: (jet2 + boson1 + boson2).Phi()), 
    '(jet2 + boson1 + boson2).M()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet2 + boson1 + boson2).M()), 
    '(jet2 + boson1 + boson2).P()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet2 + boson1 + boson2).P()), 
    '(jet2 + boson1 - boson2).Px()':                                                                      (lambda jet1, jet2, boson1, boson2: (jet2 + boson1 - boson2).Px()), 
    '(jet2 + boson1 - boson2).Py()':                                                                      (lambda jet1, jet2, boson1, boson2: (jet2 + boson1 - boson2).Py()), 
    '(jet2 + boson1 - boson2).E()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet2 + boson1 - boson2).E()), 
    '(jet2 + boson1 - boson2).Phi()':                                                                     (lambda jet1, jet2, boson1, boson2: (jet2 + boson1 - boson2).Phi()), 
    '(jet2 + boson1 - boson2).M()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet2 + boson1 - boson2).M()), 
    '(jet2 + boson1 - boson2).P()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet2 + boson1 - boson2).P()), 
    '(jet2 - boson1 + boson2).Px()':                                                                      (lambda jet1, jet2, boson1, boson2: (jet2 - boson1 + boson2).Px()), 
    '(jet2 - boson1 + boson2).Py()':                                                                      (lambda jet1, jet2, boson1, boson2: (jet2 - boson1 + boson2).Py()), 
    '(jet2 - boson1 + boson2).E()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet2 - boson1 + boson2).E()), 
    '(jet2 - boson1 + boson2).Phi()':                                                                     (lambda jet1, jet2, boson1, boson2: (jet2 - boson1 + boson2).Phi()), 
    '(jet2 - boson1 + boson2).M()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet2 - boson1 + boson2).M()), 
    '(jet2 - boson1 + boson2).P()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet2 - boson1 + boson2).P()), 
    '(jet2 - boson1 - boson2).Px()':                                                                      (lambda jet1, jet2, boson1, boson2: (jet2 - boson1 - boson2).Px()), 
    '(jet2 - boson1 - boson2).Py()':                                                                      (lambda jet1, jet2, boson1, boson2: (jet2 - boson1 - boson2).Py()), 
    '(jet2 - boson1 - boson2).E()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet2 - boson1 - boson2).E()), 
    '(jet2 - boson1 - boson2).Phi()':                                                                     (lambda jet1, jet2, boson1, boson2: (jet2 - boson1 - boson2).Phi()), 
    '(jet2 - boson1 - boson2).M()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet2 - boson1 - boson2).M()), 
    '(jet2 - boson1 - boson2).P()':                                                                       (lambda jet1, jet2, boson1, boson2: (jet2 - boson1 - boson2).P()), 
    '(jet1 + jet2 + boson1 + boson2).Px()':                                                               (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 + boson1 + boson2).Px()), 
    '(jet1 + jet2 + boson1 + boson2).Py()':                                                               (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 + boson1 + boson2).Py()), 
    '(jet1 + jet2 + boson1 + boson2).E()':                                                                (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 + boson1 + boson2).E()), 
    '(jet1 + jet2 + boson1 + boson2).Phi()':                                                              (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 + boson1 + boson2).Phi()), 
    '(jet1 + jet2 + boson1 + boson2).M()':                                                                (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 + boson1 + boson2).M()), 
    '(jet1 + jet2 + boson1 + boson2).P()':                                                                (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 + boson1 + boson2).P()), 
    '(jet1 + jet2 + boson1 - boson2).Px()':                                                               (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 + boson1 - boson2).Px()), 
    '(jet1 + jet2 + boson1 - boson2).Py()':                                                               (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 + boson1 - boson2).Py()), 
    '(jet1 + jet2 + boson1 - boson2).E()':                                                                (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 + boson1 - boson2).E()), 
    '(jet1 + jet2 + boson1 - boson2).Phi()':                                                              (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 + boson1 - boson2).Phi()), 
    '(jet1 + jet2 + boson1 - boson2).M()':                                                                (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 + boson1 - boson2).M()), 
    '(jet1 + jet2 + boson1 - boson2).P()':                                                                (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 + boson1 - boson2).P()), 
    '(jet1 + jet2 - boson1 + boson2).Px()':                                                               (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 - boson1 + boson2).Px()), 
    '(jet1 + jet2 - boson1 + boson2).Py()':                                                               (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 - boson1 + boson2).Py()), 
    '(jet1 + jet2 - boson1 + boson2).E()':                                                                (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 - boson1 + boson2).E()), 
    '(jet1 + jet2 - boson1 + boson2).Phi()':                                                              (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 - boson1 + boson2).Phi()), 
    '(jet1 + jet2 - boson1 + boson2).M()':                                                                (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 - boson1 + boson2).M()), 
    '(jet1 + jet2 - boson1 + boson2).P()':                                                                (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 - boson1 + boson2).P()), 
    '(jet1 + jet2 - boson1 - boson2).Px()':                                                               (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 - boson1 - boson2).Px()), 
    '(jet1 + jet2 - boson1 - boson2).Py()':                                                               (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 - boson1 - boson2).Py()), 
    '(jet1 + jet2 - boson1 - boson2).E()':                                                                (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 - boson1 - boson2).E()), 
    '(jet1 + jet2 - boson1 - boson2).Phi()':                                                              (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 - boson1 - boson2).Phi()), 
    '(jet1 + jet2 - boson1 - boson2).M()':                                                                (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 - boson1 - boson2).M()), 
    '(jet1 + jet2 - boson1 - boson2).P()':                                                                (lambda jet1, jet2, boson1, boson2: (jet1 + jet2 - boson1 - boson2).P()), 
    '(jet1 - jet2 + boson1 + boson2).Px()':                                                               (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 + boson1 + boson2).Px()), 
    '(jet1 - jet2 + boson1 + boson2).Py()':                                                               (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 + boson1 + boson2).Py()), 
    '(jet1 - jet2 + boson1 + boson2).E()':                                                                (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 + boson1 + boson2).E()), 
    '(jet1 - jet2 + boson1 + boson2).Phi()':                                                              (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 + boson1 + boson2).Phi()), 
    '(jet1 - jet2 + boson1 + boson2).M()':                                                                (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 + boson1 + boson2).M()), 
    '(jet1 - jet2 + boson1 + boson2).P()':                                                                (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 + boson1 + boson2).P()), 
    '(jet1 - jet2 + boson1 - boson2).Px()':                                                               (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 + boson1 - boson2).Px()), 
    '(jet1 - jet2 + boson1 - boson2).Py()':                                                               (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 + boson1 - boson2).Py()), 
    '(jet1 - jet2 + boson1 - boson2).E()':                                                                (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 + boson1 - boson2).E()), 
    '(jet1 - jet2 + boson1 - boson2).Phi()':                                                              (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 + boson1 - boson2).Phi()), 
    '(jet1 - jet2 + boson1 - boson2).M()':                                                                (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 + boson1 - boson2).M()), 
    '(jet1 - jet2 + boson1 - boson2).P()':                                                                (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 + boson1 - boson2).P()), 
    '(jet1 - jet2 - boson1 + boson2).Px()':                                                               (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 - boson1 + boson2).Px()), 
    '(jet1 - jet2 - boson1 + boson2).Py()':                                                               (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 - boson1 + boson2).Py()), 
    '(jet1 - jet2 - boson1 + boson2).E()':                                                                (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 - boson1 + boson2).E()), 
    '(jet1 - jet2 - boson1 + boson2).Phi()':                                                              (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 - boson1 + boson2).Phi()), 
    '(jet1 - jet2 - boson1 + boson2).M()':                                                                (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 - boson1 + boson2).M()), 
    '(jet1 - jet2 - boson1 + boson2).P()':                                                                (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 - boson1 + boson2).P()), 
    '(jet1 - jet2 - boson1 - boson2).Px()':                                                               (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 - boson1 - boson2).Px()), 
    '(jet1 - jet2 - boson1 - boson2).Py()':                                                               (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 - boson1 - boson2).Py()), 
    '(jet1 - jet2 - boson1 - boson2).E()':                                                                (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 - boson1 - boson2).E()), 
    '(jet1 - jet2 - boson1 - boson2).Phi()':                                                              (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 - boson1 - boson2).Phi()), 
    '(jet1 - jet2 - boson1 - boson2).M()':                                                                (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 - boson1 - boson2).M()), 
    '(jet1 - jet2 - boson1 - boson2).P()':                                                                (lambda jet1, jet2, boson1, boson2: (jet1 - jet2 - boson1 - boson2).P()), 
}